@@ -2,7 +2,7 @@
 
 # Format expected by setup.py and doc/source/conf.py: string of form "X.Y.Z"
 _version_major = 0
-_version_minor = 2
+_version_minor = 3
 _version_micro = ''  # use '' for first of series, number for 1 and above
 _version_extra = ''#'dev'
 #_version_extra = ''  # Uncomment this for full releases
@@ -40,7 +40,7 @@ TODO: more documentation will be here at some point.
 License information
 ===================
 
-Copyright (c) 2012, Max Jaderberg, Ariel Rokem 
+Copyright (c) 2012 -- , Max Jaderberg, Ariel Rokem, Haoxing Zhao
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -86,8 +86,14 @@ MINOR = _version_minor
 MICRO = _version_micro
 VERSION = __version__
 PACKAGES = ['pymatbridge']
-PACKAGE_DATA = {"pymatbridge": ["matlab/*.m", "matlab/functions/*.m",
-                                "matlab/private/*.m", "matlab/www/*.m",
-                                "test/*.m", "test/*.py", "examples/*.ipynb"]}
+PACKAGE_DATA = {"pymatbridge": ["matlab/matlabserver.m", "matlab/messenger.*",
+                                "matlab/usrprog/*", "matlab/util/*.m",
+                                "matlab/util/json_v0.2.2/LICENSE",
+                                "matlab/util/json_v0.2.2/README.md",
+                                "matlab/util/json_v0.2.2/test/*",
+                                "matlab/util/json_v0.2.2/+json/*.m",
+                                "matlab/util/json_v0.2.2/+json/java/*",
+                                "tests/*.py", "examples/*.ipynb"]}
 
 REQUIRES = []
+BIN=['scripts/publish-notebook']
